import React from 'react';

import Icon from '../Icon';
import Typography from '../Typography';

import { color as theme } from '../../constants/style';
import { Group, Item, Circle } from '../../global/toolStyled';

import data from './data';

type Props = {
  title?: string;
  selectedColor?: string;
  onClick: (color: string) => void;
  mode?: 'normal' | 'shape' | 'watermark';
};

const ColorSelector: React.FC<Props> = ({
  title = '',
  mode = 'normal',
  selectedColor = '',
  onClick,
}: Props) => (
  <>
    { title ? (
      <Typography variant="subtitle" style={{ marginTop: '8px' }} align="left">
        {title}
      </Typography>
    ) : null}
    <Group>
      {
        data.map((ele, index) => {
          if (mode === 'shape' && index === 0) {
            return (
              <Item
                key={ele.key}
                selected={selectedColor === 'transparency'}
                onMouseDown={(): void => { onClick('transparency'); }}
              >
                <Icon glyph="none" />
              </Item>
            );
          }
          if (mode === 'watermark' && index === 0) {
            const color = theme.gray;
            return (
              <Item
                key={color}
                selected={selectedColor === color}
                onMouseDown={(): void => { onClick(color); }}
              >
                <Circle color={color} />
              </Item>
            );
          }

          return (
            <Item
              key={ele.key}
              selected={selectedColor === ele.color}
              onMouseDown={(): void => { onClick(ele.color); }}
            >
              <Circle color={ele.color} />
            </Item>
          );
        })
      }
      <Item>
        <Icon glyph="color-picker" />
      </Item>
    </Group>
  </>
);

export default ColorSelector;
