import React from 'react';
import { WithTranslation } from 'next-i18next';
import { withTranslation } from '../../i18n';

import Icon from '../Icon';
import Typography from '../Typography';
import ColorSelector from '../ColorSelector';
import SliderWithTitle from '../SliderWithTitle';
import { OptionPropsType } from '../../constants/type';

import { Group, Item, Wrapper } from '../../global/toolStyled';
import data from './data';

type i18nProps = {
  t: (key: string) => string;
}

type Props = OptionPropsType & i18nProps;

const HighlightOption: React.SFC<Props> = ({
  t,
  type,
  color,
  opacity,
  setDataState = (): void => {
    // do nothing
  },
}: Props) => (
  <>
    <Wrapper>
      <Typography variant="subtitle" style={{ marginTop: '8px' }} align="left">
        {t('style')}
      </Typography>
      <Group>
        {data.lineType.map(ele => (
          <Item
            key={ele.key}
            selected={type === ele.key}
            onClick={(): void => { setDataState({ type: ele.key }); }}
          >
            <Icon glyph={ele.icon} />
          </Item>
        ))}
      </Group>
    </Wrapper>
    <Wrapper>
      <ColorSelector
        title={t('color')}
        selectedColor={color}
        onClick={(selected: string): void => { setDataState({ color: selected }); }}
      />
    </Wrapper>
    <Wrapper>
      <SliderWithTitle
        title={t('opacity')}
        value={opacity}
        tips={`${opacity}%`}
        onSlide={(val: number): void => { setDataState({ opacity: val }); }}
      />
    </Wrapper>
  </>
);

const translator = withTranslation('sidebar');

type TransProps = WithTranslation & OptionPropsType;

export default translator<TransProps>(HighlightOption);
