import React from 'react';
import { WithTranslation } from 'next-i18next';
import { withTranslation } from '../../i18n';

import { OptionPropsType } from '../../constants/type';
import Icon from '../Icon';
import Button from '../Button';
import Typography from '../Typography';
import ColorSelector from '../ColorSelector';
import SliderWithTitle from '../SliderWithTitle';

import { Group, Item, Wrapper } from '../../global/toolStyled';

type i18nProps = {
  t: (key: string) => string;
}

type Props = i18nProps & OptionPropsType;

const FreehandOption: React.SFC<Props> = ({
  t,
  type,
  color,
  opacity,
  width,
  setDataState = (): void => {
    // do nothing
  },
}: Props) => (
  <>
    <Wrapper>
      <Typography variant="subtitle" style={{ marginTop: '4px' }} align="left">
        {t('style')}
      </Typography>
      <Group>
        <Item
          size="small"
          selected={type === 'pen'}
          onClick={(): void => { setDataState({ type: 'pen' }); }}
        >
          <Icon glyph="freehand" />
        </Item>
        <Item size="small">
          <Icon glyph="eraser" />
        </Item>
        <Item size="small">
          <Icon glyph="redo" />
        </Item>
        <Item size="small">
          <Icon glyph="undo" />
        </Item>
      </Group>
    </Wrapper>
    <Wrapper>
      <ColorSelector
        title={t('color')}
        selectedColor={color}
        onClick={(selected: string): void => { setDataState({ color: selected }); }}
      />
    </Wrapper>
    <Wrapper>
      <SliderWithTitle
        title={t('opacity')}
        value={opacity}
        tips={`${opacity}%`}
        onSlide={(val: number): void => { setDataState({ opacity: val }); }}
      />
    </Wrapper>
    <Wrapper>
      <SliderWithTitle
        title={t('brushSize')}
        value={width}
        tips={`${width} pt`}
        onSlide={(val: number): void => { setDataState({ width: val }); }}
        maximum={40}
      />
    </Wrapper>
    <Wrapper>
      <Group style={{ marginTop: '20px', paddingRight: '40px' }}>
        <Button
          appearance="danger-hollow"
          shouldFitContainer
        >
          <Icon glyph="clear" style={{ marginRight: '5px' }} />
          {t('clear')}
        </Button>
      </Group>
    </Wrapper>
  </>
);

const translator = withTranslation('sidebar');

type TransProps = WithTranslation & OptionPropsType;

export default translator<TransProps>(FreehandOption);
