import React, { useEffect, useState } from 'react';
import { WithTranslation } from 'next-i18next';
import { withTranslation } from '../../i18n';

import {
  Container, Text, Input, ArrowButton,
} from './styled';

type I18nProps = {
  t: (key: string) => string;
};

type OwnerProps = {
  currentPage: number;
  totalPage: number;
  onChange: (page: number) => void;
};

type Props = OwnerProps & I18nProps;

const Pagination: React.FC<Props> = ({
  t,
  currentPage = 1,
  totalPage = 1,
  onChange = (): void => {
    // do nothing
  },
}: Props) => {
  const [inputValue, setInputValue] = useState(currentPage);

  const handleRightClick = (): void => {
    const nextPage = currentPage + 1;

    if (nextPage <= totalPage) {
      onChange(nextPage);
    }
  };

  const handleLeftClick = (): void => {
    const prevPage = currentPage - 1;

    if (prevPage > 0) {
      onChange(prevPage);
    }
  };

  const handleChange = (e: React.ChangeEvent<HTMLInputElement>): void => {
    const page = parseInt(e.target.value, 10) || 0;

    if (page >= 0 && page <= totalPage) {
      setInputValue(page);
    }
  };

  const handleKeyDown = (e: React.KeyboardEvent): void => {
    if (e.keyCode === 13) {
      onChange(inputValue);
    }
  };

  useEffect(() => {
    setInputValue(currentPage);
  }, [currentPage]);

  return (
    <Container>
      <Text>{t('page')}</Text>
      <ArrowButton onClick={handleLeftClick} variant="left" />
      <Input
        type="tel"
        onChange={handleChange}
        onKeyDown={handleKeyDown}
        value={inputValue}
      />
      <ArrowButton onClick={handleRightClick} variant="right" />
      <Text>
        {t('of')}
        {' '}
        {totalPage}
      </Text>
    </Container>
  );
};

const translator = withTranslation('toolbar');

type TransProps = WithTranslation & OwnerProps;

export default translator<TransProps>(Pagination);
