import React, { useRef, useEffect, MutableRefObject } from 'react';
import { WithTranslation } from 'next-i18next';
import { withTranslation } from '../../i18n';

import Button from '../Button';
import Portal from '../Portal';

import {
  Wrapper, InputWrapper, Input, ResultInfo, ArrowButton,
} from './styled';

type i18nProps = {
  t: (key: string) => string;
}

type OwnerProps = {
  matchesTotal: number;
  matchIndex: number;
  onEnter: (val: string) => void;
  onPrev: () => void;
  onNext: () => void;
  isActive?: boolean;
  close: () => void;
};

type Props = i18nProps & OwnerProps;

const Search: React.FC<Props> = ({
  t,
  matchesTotal = 0,
  matchIndex = 1,
  onPrev,
  onNext,
  onEnter,
  isActive = false,
  close,
}: Props) => {
  const inputRef = useRef(null) as MutableRefObject<any>;

  const handleKeyDown = (e: React.KeyboardEvent): void => {
    if (e.keyCode === 13 && inputRef.current.value) {
      onEnter(inputRef.current.value);
    }
  };

  useEffect(() => {
    if (isActive) {
      inputRef.current.focus();
    }
  }, [isActive]);

  return (
    <Portal>
      <Wrapper open={isActive}>
        <InputWrapper>
          <Input ref={inputRef} placeholder={t('searchDocument')} onKeyDown={handleKeyDown} />
          <ResultInfo>
            {matchesTotal ? `${matchIndex + 1} / ${matchesTotal}` : ''}
          </ResultInfo>
        </InputWrapper>
        <ArrowButton variant="top" onClick={onPrev} />
        <ArrowButton variant="bottom" onClick={onNext} />
        <Button appearance="primary" style={{ marginLeft: '16px' }} onClick={close}>
          {t('close')}
        </Button>
      </Wrapper>
    </Portal>
  );
};

const translator = withTranslation('toolbar');

type TransProps = WithTranslation & OwnerProps;

export default translator<TransProps>(Search);
