import React, {
  useEffect, useState, useRef, useCallback,
} from 'react';
import { fromEvent } from 'rxjs';
import {
  throttleTime,
} from 'rxjs/operators';

import {
  OuterWrapper, Wrapper, Rail, Track,
} from './styled';

type Props = {
  color?: 'primary' | 'secondary';
  minimum?: number;
  maximum?: number;
  defaultValue?: number;
  value?: number;
  disabled?: boolean;
  onChange?: (value: number) => void;
};

const Sliders: React.FC<Props> = ({
  defaultValue = 0,
  value = 0,
  onChange,
  // minimum = 0,
  maximum = 100,
}: Props) => {
  const sliderRef = useRef<HTMLDivElement>(null);
  const [valueState, setValueState] = useState(defaultValue);
  const [isActive, setActive] = useState(false);
  let subscription: any = null;

  const parseValueToPercent = (val: number): number => Math.floor(val * 100);

  const getFingerMoveValue = (event: MouseEvent | React.MouseEvent<HTMLElement>): void => {
    const { current: slider } = sliderRef;

    if (slider) {
      const { width, left } = slider.getBoundingClientRect();
      const moveDistance = event.clientX - left;
      const moveRate = moveDistance / width;
      let percent = parseValueToPercent(moveRate);

      if (percent <= 0) {
        percent = 0;
      } else if (percent >= 100) {
        percent = 100;
      }

      if (onChange) {
        const val = Math.floor(percent * (maximum * 0.01));
        onChange(val);
      }
    }
  };

  const handleTouchMove = useCallback((event: any) => {
    event.preventDefault();
    getFingerMoveValue(event);
  }, []);

  const handleTouchEnd = useCallback((event: MouseEvent) => {
    event.preventDefault();

    setActive(false);
    subscription.unsubscribe();
  }, []);

  const handleMouseDown = useCallback((event: React.MouseEvent<HTMLElement>) => {
    event.preventDefault();

    getFingerMoveValue(event);
    setActive(true);

    subscription = fromEvent(document.body, 'mousemove').pipe(throttleTime(35)).subscribe(handleTouchMove);
    document.body.addEventListener('mouseup', handleTouchEnd);
  }, []);

  const setPercent = (): void => {
    const percent = parseValueToPercent((defaultValue || value) / maximum);
    setValueState(percent);
  };

  useEffect(() => {
    setPercent();
  }, []);

  useEffect(() => {
    setPercent();
  }, [value]);

  return (
    <OuterWrapper>
      <Wrapper
        ref={sliderRef}
        onMouseDown={handleMouseDown}
      >
        <Rail track={valueState} />
        <Track
          track={valueState}
          isActive={isActive}
        />
      </Wrapper>
    </OuterWrapper>
  );
};

export default Sliders;
