import React, { useState, useEffect } from 'react';
import queryString from 'query-string';
import { withTranslation } from '../i18n';

import { ANNOTATION_TYPE } from '../constants';
import { WatermarkType, AnnotationType } from '../constants/type';
import Icon from '../components/Icon';
import Button from '../components/Button';
import Drawer from '../components/Drawer';
import WatermarkOption from '../components/WatermarkOption';

import useActions from '../actions';
import useStore from '../store';

import { BtnWrapper } from '../global/toolStyled';

type Props = {
  t: (key: string) => string;
};

const WatermarkTool: React.FC<Props> = ({
  t,
}: Props) => {
  const [isActive, setActive] = useState(false);
  const [{
    totalPage,
    watermark,
    annotations,
  }, dispatch] = useStore();
  const {
    setSidebar,
    updateWatermark,
    addAnnots,
    updateAnnots,
  } = useActions(dispatch);

  const setDataState = (obj: WatermarkType): void => {
    updateWatermark(obj);
  };

  const removeWatermarkInAnnots = (): void => {
    const index = annotations.find((ele: AnnotationType) => ele.obj_type === 'watermark');
    annotations.splice(index, 1);
    updateAnnots(annotations);
  };

  const handleClick = (): void => {
    setActive(!isActive);
    setSidebar(!isActive ? 'watermark' : '');
  };

  const handleSave = (): void => {
    const { type, imagepath, ...rest } = watermark;
    const watermarkData = {
      obj_type: ANNOTATION_TYPE.watermark,
      obj_attr: {
        ...rest,
        type,
        pages: `0-${totalPage}`,
        opacity: (watermark.opacity || 0) * 0.01,
        original_image_name: imagepath ? `temp.${imagepath.match(/image\/(.*);base64/)[1]}` : '',
        image_data: type === 'image' ? imagepath.match(/base64,(.*)/)[1] : '',
      },
    };
    removeWatermarkInAnnots();
    addAnnots([watermarkData], true);
  };

  const handleDelete = (): void => {
    removeWatermarkInAnnots();
    updateWatermark({
      ...watermark,
      text: '',
      imagepath: '',
    });
  };

  useEffect(() => {
    const parsed = queryString.parse(window.location.search);

    if (parsed.watermark) {
      setDataState({
        text: parsed.watermark as string,
      });
    }
  }, []);

  return (
    <>
      <BtnWrapper>
        <Button shouldFitContainer align="left" onClick={handleClick}>
          <Icon glyph="watermark" style={{ marginRight: '10px' }} />
          {t('watermark')}
        </Button>
      </BtnWrapper>
      <Drawer open={isActive} anchor="left" zIndex={4}>
        <WatermarkOption
          isActive={isActive}
          onClick={handleClick}
          onSave={handleSave}
          onDelete={handleDelete}
          setDataState={setDataState}
          {...watermark}
        />
      </Drawer>
    </>
  );
};

const translator = withTranslation('sidebar');

export default translator(WatermarkTool);
