import {
  WatermarkType,
} from '../constants/type';
import { floatToHex } from './utility';
import { xmlParser, getElementsByTagname } from './dom';

export const parseWatermarkFromXml = (xmlString: string): WatermarkType => {
  if (!xmlString) return {};
  const xmlDoc = xmlParser(xmlString);
  const elements = xmlDoc.firstElementChild || xmlDoc.firstChild;
  const data: WatermarkType = {};
  const element = getElementsByTagname(elements, 'watermarks');
  if (element[1]) {
    const array: any[] = Array.prototype.slice.call(element[1].childNodes);
    array.forEach((ele, index) => {
      switch (ele.tagName) {
        case 'Font':
          data.type = 'text';
          data.text = array[index + 1].textContent.trim();
          break;
        case 'Opacity': {
          data.opacity = ele.attributes.value.value * 100;
          break;
        }
        case 'Rotation': {
          data.rotation = parseFloat(ele.attributes.value.value);
          break;
        }
        case 'Scale': {
          data.scale = parseFloat(ele.attributes.value.value);
          break;
        }
        case 'Color': {
          const r = ele.attributes.r.value;
          const g = ele.attributes.g.value;
          const b = ele.attributes.b.value;
          data.textcolor = floatToHex(r, g, b);
          break;
        }
        default:
          break;
      }
    });
  }
  return data;
};

export default parseWatermarkFromXml;
